@@ -30,7 +30,7 @@ class ElasticSearchOperations:
         self.__es_port = es_port
         self.__region = region
         self.__timeout = timeout
-        self.__es = Elasticsearch([{'host': self.__es_host, 'port': self.__es_port}])
+        self.__es = Elasticsearch([{'host': self.__es_host, 'port': self.__es_port}], timeout=30, max_retries=10, retry_on_timeout=True)
 
     def __elasticsearch_get_index_hits(self, index: str, uuid: str = '', workload: str = '', fast_check: bool = False,
                                        id: bool = False):
